@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package JSON::Schema::Modern; # git description: v0.540-3-gcdc5bf90
+package JSON::Schema::Modern; # git description: v0.541-5-g4cde6982
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Validate data against a schema
 # KEYWORDS: JSON Schema data validation structure specification
 
-our $VERSION = '0.541';
+our $VERSION = '0.542';
 
 use 5.020;  # for fc, unicode_strings features
 use Moo;
@@ -100,6 +100,11 @@ has scalarref_booleans => (
   isa => Bool,
 );
 
+has strict => (
+  is => 'ro',
+  isa => Bool,
+);
+
 has _format_validations => (
   is => 'bare',
   isa => my $format_type = Dict[
@@ -151,14 +156,16 @@ sub add_schema {
       evaluator => $self,  # used mainly for traversal during document construction
     );
 
-  croak(!(caller())[0]->isa(__PACKAGE__)
-    ? join("\n", $document->errors)
-    : JSON::Schema::Modern::Result->new(
+  if ($document->has_errors) {
+    my $result = JSON::Schema::Modern::Result->new(
       output_format => $self->output_format,
       valid => 0,
       errors => [ $document->errors ],
       exception => 1,
-    )) if $document->has_errors;
+    );
+    die $result if (caller())[0]->isa(__PACKAGE__);
+    croak $result.'';
+  }
 
   if (not grep refaddr($_->{document}) == refaddr($document), $self->_canonical_resources) {
     my $schema_content = $document->_serialized_schema
@@ -423,6 +430,7 @@ sub _traverse_subschema ($self, $schema, $state) {
   return 1 if not keys %$schema;
 
   my $valid = 1;
+  my %unknown_keywords = map +($_ => undef), keys %$schema;
   # we must check the array length on every iteration because some keywords can change it!
   for (my $idx = 0; $idx <= $state->{vocabularies}->$#*; ++$idx) {
     my $vocabulary = $state->{vocabularies}[$idx];
@@ -432,6 +440,7 @@ sub _traverse_subschema ($self, $schema, $state) {
       # keywords adjacent to $ref are not evaluated before draft2019-09
       next if $keyword ne '$ref' and exists $schema->{'$ref'} and $state->{spec_version} eq 'draft7';
 
+      delete $unknown_keywords{$keyword};
       $state->{keyword} = $keyword;
       my $method = '_traverse_keyword_'.($keyword =~ s/^\$//r);
 
@@ -447,6 +456,13 @@ sub _traverse_subschema ($self, $schema, $state) {
     }
   }
 
+  delete $state->{keyword};
+
+  if ($self->strict and keys %unknown_keywords) {
+    abort($state, 'unknown keyword%s found: %s', keys %unknown_keywords > 1 ? 's' : '',
+      join(', ', sort keys %unknown_keywords));
+  }
+
   # check for previously-supported but now removed keywords
   foreach my $keyword (sort keys $removed_keywords{$state->{spec_version}}->%*) {
     next if not exists $schema->{$keyword};
@@ -537,6 +553,13 @@ sub _eval_subschema ($self, $data, $schema, $state) {
     }
   }
 
+  delete $state->{keyword};
+
+  if ($self->strict and keys %unknown_keywords) {
+    abort($state, 'unknown keyword%s found: %s', keys %unknown_keywords > 1 ? 's' : '',
+      join(', ', sort keys %unknown_keywords));
+  }
+
   $state->{annotations} = $orig_annotations;
 
   if ($valid) {
@@ -927,7 +950,7 @@ JSON::Schema::Modern - Validate data against a schema
 
 =head1 VERSION
 
-version 0.541
+version 0.542
 
 =head1 SYNOPSIS
 
@@ -1047,6 +1070,11 @@ When true, any type that is expected to be a boolean B<in the instance data> may
 as the scalar references C<\0> or C<\1> (which are serialized as booleans by JSON backends).
 Defaults to false.
 
+=head2 strict
+
+When true, unrecognized keywords are disallowed in schemas (they will cause an immediate abort
+in L</traverse> or L</evaluate>).
+
 =head1 METHODS
 
 =for Pod::Coverage BUILDARGS FREEZE THAW
@@ -1081,7 +1109,7 @@ or a URI string indicating the location where such a schema is located.
 
 Optionally, a hashref can be passed as a third parameter which allows changing the values of the
 L</short_circuit>, L</collect_annotations>, L</annotate_unknown_keywords>, L</scalarref_booleans>,
-L</validate_formats>, and/or L</validate_content_schemas>
+L</strict>, L</validate_formats>, and/or L</validate_content_schemas>
 settings for just this evaluation call.
 
 The result is a L<JSON::Schema::Modern::Result> object, which can also be used as a boolean.
@@ -1116,7 +1144,7 @@ or a URI string indicating the location where such a schema is located.
 
 Optionally, a hashref can be passed as a third parameter which allows changing the values of the
 L</short_circuit>, L</collect_annotations>, L</annotate_unknown_keywords>, L</scalarref_booleans>,
-L</validate_formats>, and/or L</validate_content_schemas>
+L</strict>, L</validate_formats>, and/or L</validate_content_schemas>
 settings for just this evaluation call.
 
 You can pass a series of callback subs to this method corresponding to keywords, which is useful for
