@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Error;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Contains a single error from a JSON Schema evaluation
 
-our $VERSION = '0.541';
+our $VERSION = '0.542';
 
 use 5.020;
 use Moo;
@@ -63,7 +63,7 @@ sub TO_JSON ($self) {
 }
 
 sub stringify ($self) {
-  '\''.$self->instance_location.'\': '.$self->error;
+  'at \''.$self->instance_location.'\': '.$self->error;
 }
 
 1;
@@ -82,7 +82,7 @@ JSON::Schema::Modern::Error - Contains a single error from a JSON Schema evaluat
 
 =head1 VERSION
 
-version 0.541
+version 0.542
 
 =head1 SYNOPSIS
 
